@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 0.16;
+our $VERSION = 0.17;
 
 use Encode::Detect::CJK qw/detect/;
 use Encode;
@@ -49,7 +49,10 @@ sub request_urls {
     my ( $self, $src_arr, %opt ) = @_;
     # arr : url / { url => .. }
     # process_sub => sub { my ($html_ref) = @_ ; ... }
-    my $arr = $opt{select_url_sub}->( $src_arr );
+    my $arr = $opt{select_url_sub} ? $opt{select_url_sub}->( $src_arr ) : $src_arr;
+
+    my $cnt = 0;
+    my @res_arr =();
     
     my $iter_sub = sub {
         my ($r) = @_;
@@ -71,17 +74,15 @@ sub request_urls {
 
     my $progress;
     $progress = Term::ProgressBar->new( { count => scalar(@$arr) } )
-      if ( $opt{show_progress_bar} );
+      if ( $opt{verbose} );
 
-    my $cnt = 0;
-    my @res_arr;
 
     my $pm = Parallel::ForkManager->new( $self->{max_process_num} );
     $pm->run_on_finish(sub {
             my ( $pid, $exit_code, $ident, $exit, $core, $data ) = @_;
 
             $cnt++;
-            $progress->update($cnt) if ( $opt{show_progress_bar} );
+            $progress->update($cnt) if ( $opt{verbose} );
             return unless ($data);
 
             my ( $id, @res ) = @$data;
@@ -90,8 +91,9 @@ sub request_urls {
 
     for my $i ( 0 .. $#$arr ) {
         my $pid = $pm->start and next;
-        my @s = $iter_sub->($arr->[$i]);
-        $pm->finish( 0, [ $i, @s ] );
+        my $r = $arr->[$i];
+        my @res = $iter_sub->($r);
+        $pm->finish( 0, [ $i, @res ]);
     }
 
     $pm->wait_all_children;
